@@ -50,13 +50,13 @@ Developer API.
    dev
 """
 
-__version__ = "0.39.2"  # denote a release candidate for 0.1.0 with 0.1rc1
+__version__ = "0.40.2"  # denote a release candidate for 0.1.0 with 0.1rc1
 
 import sys
 from os import name as _os_name
 
 from . import _check_versions  # noqa
-from . import dev
+from . import dev, test
 from ._close import close  # noqa
 from ._delete import delete  # noqa
 from ._info import info  # noqa
