@@ -3,9 +3,9 @@ from pathlib import Path
 from typing import Optional, Union
 
 import fsspec
-from cloudpathlib import CloudPath
 from dateutil.parser import isoparse  # type: ignore
 from lamin_logger import logger
+from lndb_storage import UPath, _infer_filesystem
 
 EXPIRATION_TIME = 1800  # 30 min
 
@@ -23,24 +23,17 @@ class empty_locker:
 
 
 class Locker:
-    def __init__(self, user_id: str, storage_root: Union[CloudPath, Path]):
+    def __init__(self, user_id: str, storage_root: Union[UPath, Path]):
         logger.debug(f"Init cloud sqlite locker: {user_id}, {storage_root}.")
 
         self._counter = 0
 
         self.user = user_id
 
-        root = storage_root
-        protocol = fsspec.utils.get_protocol(str(root))
+        self.root = storage_root
+        self.fs, _ = _infer_filesystem(storage_root)
 
-        if protocol == "s3":
-            fs_kwargs = {"cache_regions": True}
-        else:
-            fs_kwargs = {}
-
-        self.fs = fsspec.filesystem(protocol, **fs_kwargs)
-
-        exclusion_path = root / "exclusion"
+        exclusion_path = storage_root / "exclusion"
         self.mapper = fsspec.FSMap(str(exclusion_path), self.fs, create=True)
 
         priorities_path = str(exclusion_path / "priorities")
@@ -97,10 +90,10 @@ class Locker:
             mtime = mtime.replace(tzinfo=timezone.utc)
         return mtime.astimezone().replace(tzinfo=None)
 
-    def _msg_on_counter(self):
+    def _msg_on_counter(self, user):
         if self._counter == MAX_MSG_COUNTER:
             logger.info(
-                "Another user is doing a write operation to the database, "
+                f"Another user ({user}) is doing a write operation to the database, "
                 "please wait or stop the code execution."
             )
 
@@ -126,7 +119,7 @@ class Locker:
                 continue
 
             while int(self.mapper[f"entering/{user}"]):
-                self._msg_on_counter()
+                self._msg_on_counter(user)
             while True:
                 c_number = int(self.mapper[f"numbers/{user}"])
                 if c_number == 0:
@@ -135,7 +128,7 @@ class Locker:
                     break
                 if number == c_number and self.priority < i:
                     break
-                self._msg_on_counter()
+                self._msg_on_counter(user)
 
         self._locked = True
 
@@ -163,9 +156,14 @@ _locker: Optional[Locker] = None
 def get_locker() -> Locker:
     from .._settings import settings
 
+    user_id = settings.user.id
+    storage_root = settings.instance.storage.root
+
     global _locker
 
     if _locker is None:
-        _locker = Locker(settings.user.id, settings.instance.storage.root)
+        _locker = Locker(user_id, storage_root)
+    elif user_id != _locker.user or storage_root is not _locker.root:
+        _locker = Locker(user_id, storage_root)
 
     return _locker
