@@ -5,6 +5,7 @@ from typing import Literal, Optional, Set, Tuple, Union
 
 import sqlalchemy as sa
 import sqlmodel as sqm
+from lndb_storage import UPath
 from pydantic import PostgresDsn
 from sqlalchemy.future import Engine
 
@@ -12,7 +13,6 @@ from ._exclusion import empty_locker, get_locker
 from ._settings_save import save_instance_settings
 from ._settings_store import current_instance_settings_file, instance_settings_file
 from ._storage import Storage
-from ._upath_ext import UPath
 
 # leave commented out until we understand more how to deal with
 # migrations in redun
@@ -43,7 +43,9 @@ class InstanceSettings:
     ):
         self._owner: str = owner
         self._name: str = name
-        self._storage: Storage = Storage(storage_root, region=storage_region)
+        self._storage: Storage = Storage(
+            storage_root, instance_settings=self, region=storage_region
+        )
         self._db: Optional[str] = db
         self._schema_str: Optional[str] = schema
         self._engine: Engine = sqm.create_engine(self.db)
