@@ -2,17 +2,23 @@ import os
 from pathlib import Path
 from typing import Literal, Optional, Union
 
+import sqlmodel as sqm
 from appdirs import AppDirs
-
-from ._upath_ext import UPath
+from lndb_storage import UPath
 
 DIRS = AppDirs("lamindb", "laminlabs")
 
 
-class Storage:
-    """Manage cloud or local storage."""
+class StorageSettings:
+    """Manage cloud or local storage settings."""
 
-    def __init__(self, root: Union[str, Path, UPath], region: Optional[str] = None):
+    # we can't type instance_settings if we keep it in this separate file
+    def __init__(
+        self,
+        root: Union[str, Path, UPath],
+        instance_settings,
+        region: Optional[str] = None,
+    ):
         if isinstance(root, UPath):
             root_path = root
         elif isinstance(root, Path):
@@ -24,6 +30,8 @@ class Storage:
             raise ValueError("root should be of type Union[str, Path, UPath].")
         self._root = root_path
         self._region = region
+        self._id: Optional[str] = None
+        self._instance_settings = instance_settings
 
     @staticmethod
     def _str_to_path(storage: str) -> Union[Path, UPath]:
@@ -37,6 +45,25 @@ class Storage:
             storage_root = Path(storage).resolve()
         return storage_root
 
+    @property
+    def id(self) -> str:
+        """Storage id."""
+        if self._id is None:
+            from lnschema_core import Storage
+
+            with sqm.Session(self._instance_settings.engine) as session:
+                # needs to have been registered before!
+                storage = session.exec(
+                    sqm.select(Storage).where(Storage.root == self.root_as_str)
+                ).one_or_none()
+            if storage is None:
+                raise RuntimeError(
+                    f"{self.root_as_str} wasn't registered in the db! "
+                    "Check ln.select(ln.Storage).all()"
+                )
+            self._id = storage.id
+        return self._id
+
     @property
     def root(self) -> Union[Path, UPath]:
         """Root storage location."""
@@ -45,11 +72,7 @@ class Storage:
     @property
     def root_as_str(self) -> str:
         """Formatted root string."""
-        root_str = self.root.as_posix()
-        if root_str[-1] == "/":
-            return root_str[:-1]
-        else:
-            return root_str
+        return self.root.as_posix().rstrip("/")
 
     @property
     def cache_dir(
@@ -112,3 +135,7 @@ class Storage:
     def local_filepath(self, filekey: Union[Path, UPath, str]) -> Path:
         """Local (cache) filepath from filekey: `local(filepath(...))`."""
         return self.cloud_to_local(self.key_to_filepath(filekey))
+
+
+# below is for backward compat
+Storage = StorageSettings
